==> yst-sale-api-1.2.73-zyyy-20251013.051055-1-sources.jar: com/elitesland/sale/api/vo/param/contract/SaleContractItemSaveParam.java <==
package com.elitesland.sale.api.vo.param.contract;

import com.elitescloud.cloudt.sys.component.med.BaseModelVOMedItem;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.time.LocalDateTime;

@Data
public class SaleContractItemSaveParam extends BaseModelVOMedItem {

    private static final long serialVersionUID = 1L;

    @ApiModelProperty("记录唯一id")
    private Long id;
    @ApiModelProperty("主表ID")
    private Long masId;

    @ApiModelProperty("物料ID")
    private Long itemId;

    @ApiModelProperty("物料编码")
    private String itemCode;

    @ApiModelProperty("物料名称")
    private String itemName;

    @ApiModelProperty("物料规格")
    private String itemSpec;

    @ApiModelProperty("要求发货日期")
    private LocalDateTime shipDate;

    @ApiModelProperty("数量")
    private BigDecimal qty;

    @ApiModelProperty("订购单位")
    private String uom;

    @ApiModelProperty("基本单位数量")
    private BigDecimal baseQty;

    @ApiModelProperty("基本单位")
    private String baseUom;

    @ApiModelProperty("含税单价")
    private BigDecimal taxPrice;

    @ApiModelProperty("税率")
    private BigDecimal taxRate;

    @ApiModelProperty("不含税价")
    private BigDecimal netPrice;

    @ApiModelProperty("币种")
    private String currCode;

    @ApiModelProperty("含税金额")
    private BigDecimal amt;

    @ApiModelProperty("未税金额")
    private BigDecimal netAmt;

    @ApiModelProperty("税额")
    private BigDecimal taxAmt;
    @ApiModelProperty("渠道 yst-supp:SALE_CHANNEL")
    private String saleChannel;
    @ApiModelProperty("已执行数量")
    private BigDecimal executedQty;

    @ApiModelProperty("付款协议类型")
    private String protocolType;
    @ApiModelProperty("付款协议编码")
    private String protocolCode;
}

==> yst-sale-api-1.2.121-zyyy-20251025.011911-1-sources.jar: com/elitesland/sale/api/vo/param/contract/SaleContractItemSaveParam.java <==
package com.elitesland.sale.api.vo.param.contract;

import com.elitescloud.cloudt.sys.component.med.BaseModelVOMedItem;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import javax.persistence.Column;
import javax.persistence.Convert;
import java.io.Serializable;
import java.math.BigDecimal;
import java.time.LocalDateTime;

@Data
public class SaleContractItemSaveParam extends BaseModelVOMedItem {

    private static final long serialVersionUID = 1L;

    @ApiModelProperty("记录唯一id")
    private Long id;
    @ApiModelProperty("主表ID")
    private Long masId;

    @ApiModelProperty("物料ID")
    private Long itemId;

    @ApiModelProperty("物料编码")
    private String itemCode;

    @ApiModelProperty("物料名称")
    private String itemName;

    @ApiModelProperty("物料规格")
    private String itemSpec;

    @ApiModelProperty("行号")
    private BigDecimal lineNo;
    @ApiModelProperty("要求发货日期")
    private LocalDateTime shipDate;

    @ApiModelProperty("数量")
    private BigDecimal qty;

    @ApiModelProperty("订购单位")
    private String uom;

    @ApiModelProperty("基本单位数量")
    private BigDecimal baseQty;

    @ApiModelProperty("基本单位")
    private String baseUom;

    @ApiModelProperty("含税单价")
    private BigDecimal taxPrice;

    @ApiModelProperty("税率")
    private BigDecimal taxRate;

    @ApiModelProperty("不含税价")
    private BigDecimal netPrice;

    @ApiModelProperty("币种")
    private String currCode;

    @ApiModelProperty("含税金额")
    private BigDecimal amt;

    @ApiModelProperty("未税金额")
    private BigDecimal netAmt;

    @ApiModelProperty("税额")
    private BigDecimal taxAmt;
    @ApiModelProperty("渠道 yst-supp:SALE_CHANNEL")
    private String saleChannel;
    @ApiModelProperty("已执行数量")
    private BigDecimal executedQty;

    @ApiModelProperty("付款协议类型")
    private String protocolType;
    @ApiModelProperty("付款协议编码")
    private String protocolCode;
}
